pub struct WriteArtifact {
pub bytes: Vec<u8>,
pub merkle_root: ManifestRoot,
pub slab_bytes: Option<Vec<u8>>,
pub slab_locator: Option<String>,
pub inode_count: usize,
pub file_count: usize,
pub dir_count: usize,
pub drop_count: usize,
pub root_inode_number: u64,
}Expand description
Result of writing a directory tree.
Fields
bytes: Vec<u8>merkle_root: ManifestRootslab_bytes: Option<Vec<u8>>slab_locator: Option<String>inode_count: usizefile_count: usizedir_count: usizedrop_count: usizeroot_inode_number: u64Inode number of the root directory (i.e. the inode that represents the source directory itself, not a child of it). Always a directory and always referenced by the inlined metadata blob’s directory inode table.